@@ -29,6 +29,7 @@ import org.apache.tomcat.util.res.StringManager;
  * Coyote implementation of the servlet output stream.
  *
  * @author Costin Manolache
+ * @author Remy Maucherat
  */
 public class CoyoteOutputStream extends ServletOutputStream {
 
@@ -80,7 +81,8 @@ public class CoyoteOutputStream extends ServletOutputStream {
         try {
             ob.writeByte(i);
         } catch (IOException ioe) {
-            handleIOException(ioe);
+            ob.setErrorException(ioe);
+            throw ioe;
         }
         if (nonBlocking) {
             checkRegisterForWrite();
@@ -100,7 +102,8 @@ public class CoyoteOutputStream extends ServletOutputStream {
         try {
             ob.write(b, off, len);
         } catch (IOException ioe) {
-            handleIOException(ioe);
+            ob.setErrorException(ioe);
+            throw ioe;
         }
         if (nonBlocking) {
             checkRegisterForWrite();
@@ -108,13 +111,18 @@ public class CoyoteOutputStream extends ServletOutputStream {
     }
 
 
+    @Override
     public void write(ByteBuffer from) throws IOException {
         Objects.requireNonNull(from);
         boolean nonBlocking = checkNonBlockingWrite();
+        if (from.remaining() == 0) {
+            return;
+        }
         try {
             ob.write(from);
         } catch (IOException ioe) {
-            handleIOException(ioe);
+            ob.setErrorException(ioe);
+            throw ioe;
         }
         if (nonBlocking) {
             checkRegisterForWrite();
@@ -131,7 +139,8 @@ public class CoyoteOutputStream extends ServletOutputStream {
         try {
             ob.flush();
         } catch (IOException ioe) {
-            handleIOException(ioe);
+            ob.setErrorException(ioe);
+            throw ioe;
         }
         if (nonBlocking) {
             checkRegisterForWrite();
@@ -170,7 +179,8 @@ public class CoyoteOutputStream extends ServletOutputStream {
         try {
             ob.close();
         } catch (IOException ioe) {
-            handleIOException(ioe);
+            ob.setErrorException(ioe);
+            throw ioe;
         }
     }
 
@@ -187,29 +197,5 @@ public class CoyoteOutputStream extends ServletOutputStream {
     public void setWriteListener(WriteListener listener) {
         ob.setWriteListener(listener);
     }
-
-
-    private void handleIOException(IOException ioe) throws IOException {
-        try {
-            ob.setErrorException(ioe);
-        } catch (NullPointerException npe) {
-            /*
-             * Ignore.
-             *
-             * An IOException on a non-container thread during asynchronous Servlet processing will trigger a dispatch
-             * to a container thread that will complete the asynchronous processing and recycle the request, response
-             * and associated objects including the OutputBuffer. Depending on timing it is possible that the
-             * OutputBuffer will have been cleared by the time the call above is made - resulting in an NPE.
-             *
-             * If the OutputBuffer is null then there is no need to call setErrorException(). Catching and ignoring the
-             * NPE is (for now at least) a simpler solution than adding locking to OutputBuffer to ensure it is non-null
-             * and remains non-null while setErrorException() is called.
-             *
-             * The longer term solution is likely a refactoring and clean-up of error handling for asynchronous requests
-             * but that is potentially a significant piece of work.
-             */
-        }
-        throw ioe;
-    }
 }
 
