@@ -1048,20 +1048,6 @@ public class ExpiresFilter extends FilterBase {
         return ints;
     }
 
-    /**
-     * Convert a given comma delimited list of strings into an array of String
-     *
-     * @param commaDelimitedStrings the string to be split
-     *
-     * @return array of patterns (non {@code null})
-     *
-     * @deprecated Unused. Will be removed in Tomcat 11.
-     */
-    @Deprecated
-    protected static String[] commaDelimitedListToStringArray(String commaDelimitedStrings) {
-        return StringUtils.splitCommaSeparated(commaDelimitedStrings);
-    }
-
     /**
      * @return {@code true} if the given {@code str} contains the given {@code searchStr}.
      *
@@ -1397,17 +1383,9 @@ public class ExpiresFilter extends FilterBase {
      */
     protected boolean isEligibleToExpirationHeaderGeneration(HttpServletRequest request,
             XHttpServletResponse response) {
-
-        // Don't add cache headers unless the request is a GET or a HEAD request
-        String method = request.getMethod();
-        if (!"GET".equals(method) && !"HEAD".equals(method)) {
-            if (log.isDebugEnabled()) {
-                log.debug(sm.getString("expiresFilter.invalidMethod", request.getRequestURI(), method));
-            }
-            return false;
-        }
-
-        if (response.containsHeader(HEADER_EXPIRES) || contains(response.getCacheControlHeader(), "max-age")) {
+        boolean expirationHeaderHasBeenSet =
+                response.containsHeader(HEADER_EXPIRES) || contains(response.getCacheControlHeader(), "max-age");
+        if (expirationHeaderHasBeenSet) {
             if (log.isDebugEnabled()) {
                 log.debug(sm.getString("expiresFilter.expirationHeaderAlreadyDefined", request.getRequestURI(),
                         Integer.valueOf(response.getStatus()), response.getContentType()));
@@ -1415,14 +1393,6 @@ public class ExpiresFilter extends FilterBase {
             return false;
         }
 
-        if (contains(response.getCacheControlHeader(), "no-store")) {
-            if (log.isDebugEnabled()) {
-                log.debug(sm.getString("expiresFilter.cacheControlNoStore", request.getRequestURI(),
-                        Integer.valueOf(response.getStatus()), response.getContentType()));
-            }
-            return false;
-        }
-
         for (int skippedStatusCode : this.excludedResponseStatusCodes) {
             if (response.getStatus() == skippedStatusCode) {
                 if (log.isDebugEnabled()) {
